# coding:utf-8
# @Time    : 2019-12-12
# @Author  : Kevin Kong (kfx2007@163.com)

from .comm import Comm


class Base(Comm):

    def get_express_time(self, commonDistrID=None):
        """
        时效查询
        """
        method = "open.api.openCommon.queryTimeliness"
        pass

    def get_address(self, distrctId=None):
        """五级地址多级联动查询(V1.0)"""

        method = "open.api.openCommon.queryKyeAddress"
        data = {
            "commonDistrID": distrctId
        }
        return self.post(method, data=data).json()

    def is_cross_district(self, adresses, company_no=None):
        """根据收件地址判断是否在派送区域内"""
        method = "open.api.openCommon.queryOverZoneInfo"
        data = {
            "companyNo": company_no,
            "addressData": adresses
        }
        return self.post(method, data).json()

    def get_route_info(self, express_nos=None, codes=None):
        """查询路由信息"""
        method = "open.api.openCommon.queryPublicRoute"
        data = {
            "waybillNumbers": express_nos,
            "productCodes": codes,
        }
        return self.post(method, data).json()



# coding:utf-8
# @Time    : 2019-12-09
# @Author  : Kevin Kong (kfx2007@163.com)

from .comm import Comm
from .order import Order
from .base import Base


class KY(object):

    def __init__(self, appkey, appsecret, sandbox=False):
        self.appkey = appkey
        self.appsecret = appsecret
        self.sandbox = sandbox

    comm = Comm()
    order = Order()
    base = Base()



# coding:utf-8
# @Time    : 2019-12-09
# @Author  : Kevin Kong (kfx2007@163.com)

import requests
import time
from hashlib import md5
import json

TOKEN_URL = "https://open.ky-express.com/security/token"
SANDBOX_TOKEN_URL = "https://open.ky-express.com/security/sandbox/accessToken"
REFESH_URL = "https://open.ky-express.com/security/token/refresh"
API_URL = "https://open.ky-express.com/router/rest"
SANDBOX_URL = "https://open.ky-express.com/sandbox/router/rest"


class Comm(object):

    def __get__(self, instance, type):
        self.appkey = instance.appkey
        self.appsecret = instance.appsecret
        self.sandbox = instance.sandbox
        return self

    def _get_token(self):
        """获取TOKEN"""
        headers = {"Content-Type": "application/json", "X-from": "openapi_app"}
        url = SANDBOX_TOKEN_URL if self.sandbox else TOKEN_URL
        res = requests.post(url, json={
            "appkey": self.appkey,
            "appsecret": self.appsecret
        }, headers=headers).json()
        if res["success"]:
            return res["data"]["token"], res["data"]["refresh_token"]

    def _refresh_token(self, refresh_token):
        """刷新token"""
        headers = {"Content-Type": "application/json", "X-from": "openapi_app"}
        res = requests.post(REFESH_URL, json={
            "refresh_token": refresh_token
        }, headers=headers).json()
        if res["success"]:
            return res["data"]["refresh_token"]

    def _get_request_header(self, timestamp):
        token, _ = self._get_token()
        return {
            "X-from": "openapi_app",
            "Content-Type": "application/json",
            "token": token,
            "appkey": self.appkey,
            "timestamp": timestamp,
            "format": "json"
        }

    def _sign(self, params, timestamp):
        return md5("{}{}{}".format(self.appsecret, timestamp, params).encode('utf-8')).hexdigest().upper()

    def post(self, method, data=None):
        # 这里吐槽一下跨越官方 不仅没有Python版的SDK，即使是Java和Net，居然也只是放了个DLL进去，源码都不带给的。。
        timestamp = str(int(round(time.time()*1000)))
        headers = self._get_request_header(timestamp)
        # 去除空值
        data = {key: val for key, val in data.items() if val}
        sign = self._sign(json.dumps(data), timestamp)
        headers['method'] = method
        headers['sign'] = sign
        url = SANDBOX_URL if self.sandbox else API_URL
        return requests.post(url, json=data, headers=headers)



# coding:utf-8
# @Time    : 2019-12-12
# @Author  : Kevin Kong (kfx2007@163.com)

from .comm import Comm


class Order(Comm):

    def get_express_number(self, count=1):
        """
        获取运单号接口

        param count: 运单号个数
        """
        method = "open.api.openCommon.queryWaybillNumber"
        return self.post(method, {'count': count}).json()



import codecs
import os
import sys
import ky
try:
	from setuptools import setup, find_packages
except:
	from distutils.core import setup

def read(fname):
    return codecs.open(os.path.join(os.path.dirname(__file__), fname)).read()

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md')) as f:
    long_description = f.read()

setup(
    name = "ky-sdk",
    version = ky.__version__,
    description = "KuaYue Express Python SDK",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    classifiers =
	[
        'License :: OSI Approved :: GNU Affero General Public License v3',
        'Programming Language :: Python',
        'Operating System :: OS Independent',
		'Topic :: Scientific/Engineering :: Astronomy',
		'Topic :: Scientific/Engineering :: GIS',
		'Topic :: Scientific/Engineering :: Mathematics',
		'Intended Audience :: Science/Research',
		'Intended Audience :: Developers',
		'Intended Audience :: Information Technology',
    ],
    keywords = "ky sdk",
    author = "blackcat",
    author_email = "kfx2007@163.com",
    url ="https://github.com/block-cat/ky-sdk",
    license = "GNU",
    packages = find_packages(),
    include_package_data= True,
    install_requires=[
        'requests',
    ],
    setup_requires=[
        'requests',
    ],
    zip_safe= True,
)